MutualFundsInfo class

Constructors

MutualFundsInfo()

Properties

hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

about() String
fetchNavBySchemeCode(String schemeCode) Future<List<Map<String, String>>>
fetchNavBySchemeName(String schemeName) Future<List<Map<String, String>>>
getAllNavs() Future<List<Map<String, String>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited