Method to fetch NAV data from the URL
Given a URL, this function fetches the data from the given URL.
It resolves with the fetched data if there is no error.
Otherwise, it rejects with an error message.
@param {String} url - URL to fetch data from
@returns {Future<String>}
Given a text fetched from the NAV URL, this function
returns an array of objects. Each object represents
a mutual fund and contains its details.
@param {String} txt - the text fetched from the NAV URL
@returns {List<Map<String, String>>> an array of objects, each representing a mutual fund